.. :changelog:

History
-------

0.2.2 (2021-06-01)
++++++++++++++++++

* Fixed related_name and related_query_name at AbstractOfficialArea model
* Updated python-slugify according its documentation


0.2.1 (2021-03-19)
++++++++++++++++++

* Added BaseInspireEUModel at CadastralZoning and CadastralParcel
* Typo fixed AbstractCadastralParcel.national_cadastal_reference to AbstractCadastralParcel.national_cadastral_reference

0.2.0 (2021-02-26)
++++++++++++++++++

* First release on PyPI.

0.1.0 (2021-02-07)
++++++++++++++++++

* First release on GitHub.
